#!/usr/bin/env python
#
# A simple looping player.
# Version 2, based on "about-to-finish" handling.
#
# Get a test sample with:
# youtube-dl -t http://www.youtube.com/watch?v=yWa-YXiSk2Y

import sys

import gi
gi.require_version('Gst', '1.0')
from gi.repository import Gst
Gst.init(None)

from gi.repository import GObject
GObject.threads_init()


class Player:
    def __init__(self, uri):
        self._uri = uri
        self._player = Gst.ElementFactory.make("playbin", "player")
        self._player.set_property("uri", uri)
        self._player.connect("about-to-finish", self.on_about_to_finish)

        bus = self._player.get_bus()
        bus.add_signal_watch()
        bus.connect('message::error', self.on_error)

    def run(self):
        self._player.set_state(Gst.State.PLAYING)
        self.loop = GObject.MainLoop()
        self.loop.run()

    def quit(self):
        self._player.set_state(Gst.State.NULL)
        self.loop.quit()

    def on_about_to_finish(self, player):
        sys.stderr.write(".")
        player.set_property("uri", self._uri)

    def on_error(self, bus, msg):
        (err, debug) = msg.parse_error()
        print "Error: %s" % err, debug
        self.quit()


def main(args):
    def usage():
        sys.stdout.write("usage: %s <filename>\n" % args[0])

    if len(args) != 2:
        usage()
        sys.exit(1)

    uri = Gst.filename_to_uri(args[1])

    player = Player(uri)
    player.run()

if __name__ == '__main__':
    sys.exit(main(sys.argv))
